@@ -26,7 +26,7 @@ author_doc = 'Ann Crabbé (KU Leuven)'
 author_email = 'acrabbe.foss@gmail.com'
 author_copyright = '© 2018 - 2020 by Ann Crabbé (KU Leuven)'
 short_version = '1.0'
-long_version = '1.0.1'
+long_version = '1.0.3'
 
 bitbucket_home = 'https://bitbucket.org/kul-reseco/lnns'
 bitbucket_src = 'https://bitbucket.org/kul-reseco/lnns/src'
@@ -47,4 +47,4 @@ long_description = 'Supervised classification of an multi-band image using an ML
 icon = 'images/lumos_h50.png'
 qgis_category = 'Raster'
 
-hasProcessingProvider = 'yes'
+processing_provider = 'yes'
